Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(15)

Unified Diff: content/common/gpu/media/omx_video_decode_accelerator.h

Issue 7021020: Clean up video frame sizes, types in Video Decode API (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: responses to CR Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/gpu/media/omx_video_decode_accelerator.h
diff --git a/content/common/gpu/media/omx_video_decode_accelerator.h b/content/common/gpu/media/omx_video_decode_accelerator.h
index edced282a9248fa982c0325214f219cfd1b90743..f48d7e1c489e134e60df93beaabf2a010df6fe9d 100644
--- a/content/common/gpu/media/omx_video_decode_accelerator.h
+++ b/content/common/gpu/media/omx_video_decode_accelerator.h
@@ -44,8 +44,8 @@ class OmxVideoDecodeAccelerator : public media::VideoDecodeAccelerator {
// media::VideoDecodeAccelerator implementation.
bool Initialize(const std::vector<uint32>& config) OVERRIDE;
void Decode(const media::BitstreamBuffer& bitstream_buffer) OVERRIDE;
- virtual void AssignGLESBuffers(
- const std::vector<media::GLESBuffer>& buffers) OVERRIDE;
+ virtual void AssignPictureBuffers(
+ const std::vector<media::PictureBuffer>& buffers) OVERRIDE;
void ReusePictureBuffer(int32 picture_buffer_id) OVERRIDE;
void Flush() OVERRIDE;
void Reset() OVERRIDE;
@@ -70,12 +70,12 @@ class OmxVideoDecodeAccelerator : public media::VideoDecodeAccelerator {
};
// Helper struct for keeping track of the relationship between an OMX output
// buffer and the GLESBuffer it points to.
struct OutputPicture {
- OutputPicture(media::GLESBuffer g_b, OMX_BUFFERHEADERTYPE* o_b_h,
+ OutputPicture(media::PictureBuffer p_b, OMX_BUFFERHEADERTYPE* o_b_h,
EGLImageKHR e_i)
- : gles_buffer(g_b), omx_buffer_header(o_b_h), egl_image(e_i) {}
- media::GLESBuffer gles_buffer;
+ : picture_buffer(p_b), omx_buffer_header(o_b_h), egl_image(e_i) {}
+ media::PictureBuffer picture_buffer;
OMX_BUFFERHEADERTYPE* omx_buffer_header;
EGLImageKHR egl_image;
};
@@ -70,12 +70,12 @@ class OmxVideoDecodeAccelerator : public media::VideoDecodeAccelerator {
};
// Helper struct for keeping track of the relationship between an OMX output
- // buffer and the GLESBuffer it points to.
+ // buffer and the PictureBuffer it points to.
struct OutputPicture {
« no previous file with comments | « content/common/gpu/media/gpu_video_decode_accelerator.cc ('k') | content/common/gpu/media/omx_video_decode_accelerator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698